==> apache-seata-2.3.0-incubating-src.tar.gz: apache-seata-2.3.0-incubating-src/tm/src/test/java/org/apache/seata/tm/api/transaction/NoRollbackRuleTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.seata.tm.api.transaction;

import org.junit.jupiter.api.Assertions;
import org.junit.jupiter.api.Test;

/**
  */
public class NoRollbackRuleTest {

    @Test
    public void equalsTest(){
        RollbackRule rollbackRuleByClass = new NoRollbackRule(Exception.class);
        RollbackRule otherRollbackRuleByClass = new NoRollbackRule(Exception.class);
        Assertions.assertEquals(rollbackRuleByClass, otherRollbackRuleByClass);
        RollbackRule rollbackRuleByName = new NoRollbackRule(Exception.class.getName());
        RollbackRule otherRollbackRuleByName = new NoRollbackRule(Exception.class.getName());
        Assertions.assertEquals(rollbackRuleByName, otherRollbackRuleByName);
        NoRollbackRule otherRollbackRuleByName3 = new NoRollbackRule(Exception.class.getName());
        Assertions.assertEquals(otherRollbackRuleByName3.toString(),"NoRollbackRule with pattern [" + Exception.class.getName() + "]");


    }
}

==> apache-seata-2.5.0-incubating-src.tar.gz: apache-seata-2.5.0-incubating-src/tm/src/test/java/org/apache/seata/tm/api/transaction/NoRollbackRuleTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.seata.tm.api.transaction;

import org.junit.jupiter.api.Assertions;
import org.junit.jupiter.api.Test;

/**
 */
public class NoRollbackRuleTest {

    @Test
    public void equalsTest() {
        RollbackRule rollbackRuleByClass = new NoRollbackRule(Exception.class);
        RollbackRule otherRollbackRuleByClass = new NoRollbackRule(Exception.class);
        Assertions.assertEquals(rollbackRuleByClass, otherRollbackRuleByClass);
        RollbackRule rollbackRuleByName = new NoRollbackRule(Exception.class.getName());
        RollbackRule otherRollbackRuleByName = new NoRollbackRule(Exception.class.getName());
        Assertions.assertEquals(rollbackRuleByName, otherRollbackRuleByName);
        NoRollbackRule otherRollbackRuleByName3 = new NoRollbackRule(Exception.class.getName());
        Assertions.assertEquals(
                otherRollbackRuleByName3.toString(), "NoRollbackRule with pattern [" + Exception.class.getName() + "]");
    }
}
